---
description: Instructions for installing Docker Desktop on Ubuntu
keywords: Ubuntu, install, uninstall, upgrade, update, Linux, desktop, Docker desktop, docker desktop for Linux, DD4L
title: Install on Ubuntu
toc_max: 4
redirect_from:
  - /desktop/linux/install/ubuntu/
---

This page contains information on how to install, launch and upgrade Docker Desktop on an Ubuntu distribution.

[DEB package](https://desktop.docker.com/linux/main/amd64/docker-desktop-4.15.0-amd64.deb?utm_source=docker&utm_medium=webreferral&utm_campaign=docs-driven-download-linux-amd64){: .button .primary-btn }

_For checksums, see [Release notes](../release-notes.md)_

## Prerequisites

To install Docker Desktop successfully, you must:

- Meet the [system requirements](linux-install.md#system-requirements)
- Have a 64-bit version of either Ubuntu Jammy Jellyfish 22.04 (LTS) or Ubuntu Impish Indri 21.10.
  Docker Desktop is supported on `x86_64` (or `amd64`) architecture.
- For non-Gnome Desktop environments, `gnome-terminal` must be installed:
  ```console
  $ sudo apt install gnome-terminal
  ```
- Uninstall the tech preview or beta version of Docker Desktop for Linux. Run:

  ```console
  $ sudo apt remove docker-desktop
  ```

  For a complete cleanup, remove configuration and data files at `$HOME/.docker/desktop`, the symlink at `/usr/local/bin/com.docker.cli`, and purge the remaining systemd service files.

  ```console
  $ rm -r $HOME/.docker/desktop
  $ sudo rm /usr/local/bin/com.docker.cli
  $ sudo apt purge docker-desktop
  ```

  > **Note**
  >
  > If you have installed the Docker Desktop for Linux tech preview or beta version, you need to remove all files that were generated by those packages (e.g., `~/.config/systemd/user/docker-desktop.service`, `~/.local/share/systemd/user/docker-desktop.service`).

## Install Docker Desktop

Recommended approach to install Docker Desktop on Ubuntu:

1. Set up [Docker's package repository](../../engine/install/ubuntu.md#set-up-the-repository).

2. Download latest [DEB package](https://desktop.docker.com/linux/main/amd64/docker-desktop-4.15.0-amd64.deb?utm_source=docker&utm_medium=webreferral&utm_campaign=docs-driven-download-linux-amd64).

3. Install the package with apt as follows:

   ```console
   $ sudo apt-get update
   $ sudo apt-get install ./docker-desktop-<version>-<arch>.deb
   ```

   > **Note**
   >
   > At the end of the installation process, `apt` displays an error due to installing a downloaded package. You
   > can ignore this error message.
   >
   > ```
   > N: Download is performed unsandboxed as root, as file '/home/user/Downloads/docker-desktop.deb' couldn't be accessed by user '_apt'. - pkgAcquire::Run (13: Permission denied)
   > ```

There are a few post-install configuration steps done through the post-install script contained in the deb package.

The post-install script:

- Sets the capability on the Docker Desktop binary to map privileged ports and set resource limits.
- Adds a DNS name for Kubernetes to `/etc/hosts`.
- Creates a link from `/usr/bin/docker` to `/usr/local/bin/com.docker.cli`.

## Launch Docker Desktop

{% include desktop-linux-launch.md %}

## Upgrade Docker Desktop

Once a new version for Docker Desktop is released, the Docker UI shows a notification.
You need to download the new package each time you want to upgrade Docker Desktop and run:

```console
$ sudo apt-get install ./docker-desktop-<version>-<arch>.deb
```

## Next steps

- Take a look at the [Get started](../../get-started/index.md) training modules to learn how to build an image and run it as a containerized application.
- Review the topics in [Develop with Docker](../../develop/index.md) to learn how to build new applications using Docker.
